aboutsummaryrefslogtreecommitdiffstats
path: root/c/cat.c
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--c/cat.c18
1 files changed, 12 insertions, 6 deletions
diff --git a/c/cat.c b/c/cat.c
index 4092778..dde58cd 100644
--- a/c/cat.c
+++ b/c/cat.c
@@ -1,10 +1,16 @@
#include "gbos.h"
/* cat: copy stdin to stdout until EOF (Ctrl-D / pipe end). */
void main(void) {
- char c;
- for (;;) {
- c = readc();
- if (c == EOF) break;
- putc(c);
+ char *argv[4];
+ unsigned char argc = argv_parse(argv, 4);
+ if (argc > 0) {
+ unsigned char fd = open(argv[0], O_READ);
+ int ch;
+ if (fd == NOFD) { puts("cat: no such file"); nl(); return; }
+ while ((ch = fgetc(fd)) >= 0) putc((char)ch);
+ close(fd);
+ } else {
+ char c;
+ for (;;) { c = readc(); if (c == EOF) break; putc(c); }
}
}
@@ -1,10 +1,16 @@
#include "gbos.h"
-/* cat: copy stdin to stdout until EOF (Ctrl-D / pipe end). */
+/* cat [file]: print a file, or copy stdin to stdout until EOF. */
void main(void) {